============
Installation
============

At the command line::

    $ pip install django-mysql

Or add it to your project's ``requirements.txt``.

...or if you're really still using it::

    $ easy_install django-mysql
